##  Procedure
  1. From the [SAP for Me](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com") page, select Systems & Provisioning. ![The SAP for Me dashboard with Systems & Provisioning highlighted in the side menu.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio708a65ef92be4850905fd1e540733726_HiRes.png)
  2. On the Provisioning tab, go to the Systems to be Provisioned table.
  3. To find the product, use the search field above the table and enter SAP LeanIX.
  4. Select SAP LeanIX.
  5. **Tip**
You can provision sandbox and production workspaces in SAP for Me. Ensure to pick the correct system role:
     * Sandbox workspace: System role Test
     * Production: System role Production
Choose Start Provisioning. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio37fa460a75ac4b4d9d5d41511dfe4372_HiRes.png)
  6. In the Start New Provisioning Request overlay, check and update the information. Choose Submit to start the provisioning process.
A confirmation message notifies you that the provisioning request is sent.
You can track the status of the provisioning in the Provisioned Systems table. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio199c00d94fa849d5888b9915097b92af_HiRes.png)
